@@ -3,8 +3,9 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate musical cadence chords
 
-our $VERSION = '0.1404';
+our $VERSION = '0.1500';
 
+use List::Util 'any';
 use Moo;
 use Music::Chord::Note;
 use Music::Chord::Positions;
@@ -275,6 +276,17 @@ sub _generate_chord {
     return \@notes;
 }
 
+
+sub remove_notes {
+    my ($self, $indices, $chord) = @_;
+    my @chord;
+    for my $n (0 .. @$chord - 1) {
+        next if any { $n == $_ } @$indices;
+        push @chord, $chord->[$n];
+    }
+    return \@chord;
+}
+
 1;
 
 __END__
@@ -289,7 +301,7 @@ Music::Cadence - Generate musical cadence chords
 
 =head1 VERSION
 
-version 0.1404
+version 0.1500
 
 =head1 SYNOPSIS
 
@@ -354,6 +366,9 @@ version 0.1404
   );
   # [F4 G5 B5 D5], [E4 G4 A#4 C5]
 
+  my $altered = $mc->remove_notes([1,2], [qw(Gs5 C5 Ds5)]);
+  # [Gs5]
+
 =head1 DESCRIPTION
 
 C<Music::Cadence> generates a pair of musical cadence chords.
@@ -554,10 +569,18 @@ Here is a summary showing resolutions and options:
 
  6. Plagal -> IV-I
 
+=head2 remove_notes
+
+  $altered = $mc->remove_notes(\@indices, \@chord);
+
+Remove the given indices from the given chord.
+
 =head1 SEE ALSO
 
 The F<eg/*> and F<t/*> programs in this distribution
 
+L<List::Util>
+
 L<Moo>
 
 L<Music::Chord::Note>
